@@ -17,6 +17,14 @@ struct TestGenerics<A, B, C> {
   baz: C,
 }
 
+#[derive(FieldNamesAsArray)]
+struct TestSkip {
+  a: String,
+  b: String,
+  #[field_names_as_array(skip)]
+  c: String,
+}
+
 #[test]
 fn test_struct() {
   assert_eq!(Test::FIELD_NAMES_AS_ARRAY, ["f1", "f2", "f3", "f4"]);
@@ -29,3 +37,8 @@ fn test_generics_struct() {
     ["foo", "bar", "baz"],
   );
 }
+
+#[test]
+fn test_skip() {
+  assert_eq!(TestSkip::FIELD_NAMES_AS_ARRAY, ["a", "b"]);
+}
